@@ -182,7 +182,7 @@ gail_label_real_initialize (AtkObject *obj,
     gail_label->label_length = g_utf8_strlen (label_text, -1);
 
   /* 
-   * Check whether ancestor of GtkLabel is a GtkButton  and if so
+   * Check whether ancestor of GtkLabel is a GtkButton and if so
    * set accessible parent for GailLabel
    */
   widget = GTK_WIDGET (data);
@@ -195,6 +195,11 @@ gail_label_real_initialize (AtkObject *obj,
           break;
         }
     }
+
+  if (GTK_IS_ACCEL_LABEL (widget))
+    obj->role = ATK_ROLE_ACCEL_LABEL;
+  else
+    obj->role = ATK_ROLE_LABEL;
 }
 
 AtkObject* 
@@ -210,11 +215,6 @@ gail_label_new (GtkWidget *widget)
   accessible = ATK_OBJECT (object);
   atk_object_initialize (accessible, widget);
 
-  if (GTK_IS_ACCEL_LABEL (widget))
-    accessible->role = ATK_ROLE_ACCEL_LABEL;
-  else
-    accessible->role = ATK_ROLE_LABEL;
-
   return accessible;
 }
 
